==> pointpos_api-0.0.1.tar.gz: docs/RecipeApi.md <==
# swagger.api.RecipeApi

## Load the API package
```dart
import 'package:swagger/api.dart';
```

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createRecipe**](RecipeApi.md#createRecipe) | **POST** /recipe | Create Recipe
[**deleteRecipeByID**](RecipeApi.md#deleteRecipeByID) | **DELETE** /recipe/{itemId} | Delete Recipe By ID
[**findRecipe**](RecipeApi.md#findRecipe) | **GET** /recipe | Get Recipe List
[**getRecipeByID**](RecipeApi.md#getRecipeByID) | **GET** /recipe/{itemId} | Get Recipe By ID
[**updateRecipeByID**](RecipeApi.md#updateRecipeByID) | **PUT** /recipe/{itemId} | Update Recipe By ID


# **createRecipe**
> Recipe createRecipe(authorization, xAPIKey, body)

Create Recipe

Create Recipe

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RecipeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var body = new Recipe(); // Recipe | 

try { 
    var result = api_instance.createRecipe(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling RecipeApi->createRecipe: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **body** | [**Recipe**](Recipe.md)|  | 

### Return type

[**Recipe**](Recipe.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteRecipeByID**
> deleteRecipeByID(authorization, xAPIKey, itemId)

Delete Recipe By ID

Delete Recipe By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RecipeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var itemId = itemId_example; // String | 

try { 
    api_instance.deleteRecipeByID(authorization, xAPIKey, itemId);
} catch (e) {
    print("Exception when calling RecipeApi->deleteRecipeByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **itemId** | **String**|  | 

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findRecipe**
> List<Recipe> findRecipe(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Recipe List

Get Recipe  List

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RecipeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"itemId\"   - \"variantId\"   - \"ingredients\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findRecipe(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling RecipeApi->findRecipe: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10]
 **offset** | **num**|  | [optional] [default to 0]
 **sort** | **String**|  | [optional] 
 **direction** | **String**|  | [optional] 
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;itemId\&quot;   - \&quot;variantId\&quot;   - \&quot;ingredients\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] 

### Return type

[**List<Recipe>**](Recipe.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getRecipeByID**
> Recipe getRecipeByID(authorization, xAPIKey, itemId)

Get Recipe By ID

Get Recipe By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RecipeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var itemId = itemId_example; // String | 

try { 
    var result = api_instance.getRecipeByID(authorization, xAPIKey, itemId);
    print(result);
} catch (e) {
    print("Exception when calling RecipeApi->getRecipeByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **itemId** | **String**|  | 

### Return type

[**Recipe**](Recipe.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateRecipeByID**
> Recipe updateRecipeByID(authorization, xAPIKey, itemId, body)

Update Recipe By ID

Update [object Object] By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RecipeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var itemId = itemId_example; // String | 
var body = new Recipe(); // Recipe | 

try { 
    var result = api_instance.updateRecipeByID(authorization, xAPIKey, itemId, body);
    print(result);
} catch (e) {
    print("Exception when calling RecipeApi->updateRecipeByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **itemId** | **String**|  | 
 **body** | [**Recipe**](Recipe.md)|  | 

### Return type

[**Recipe**](Recipe.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.0.2.tar.gz: docs/RecipeApi.md <==
# swagger.api.RecipeApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createRecipe**](RecipeApi.md#createRecipe) | **POST** /recipe | Create Recipe
[**deleteRecipeByID**](RecipeApi.md#deleteRecipeByID) | **DELETE** /recipe/{itemId} | Delete Recipe By ID
[**findRecipe**](RecipeApi.md#findRecipe) | **GET** /recipe | Get Recipe List
[**getRecipeByID**](RecipeApi.md#getRecipeByID) | **GET** /recipe/{itemId} | Get Recipe By ID
[**updateRecipeByID**](RecipeApi.md#updateRecipeByID) | **PUT** /recipe/{itemId} | Update Recipe By ID


# **createRecipe**
> Recipe createRecipe(authorization, xAPIKey, body)

Create Recipe

Create Recipe

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RecipeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var body = new Recipe(); // Recipe | 

try { 
    var result = api_instance.createRecipe(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling RecipeApi->createRecipe: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **body** | [**Recipe**](Recipe.md)|  | 

### Return type

[**Recipe**](Recipe.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteRecipeByID**
> deleteRecipeByID(authorization, xAPIKey, itemId)

Delete Recipe By ID

Delete Recipe By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RecipeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var itemId = itemId_example; // String | 

try { 
    api_instance.deleteRecipeByID(authorization, xAPIKey, itemId);
} catch (e) {
    print("Exception when calling RecipeApi->deleteRecipeByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **itemId** | **String**|  | 

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findRecipe**
> List<Recipe> findRecipe(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Recipe List

Get Recipe  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RecipeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"itemId\"   - \"variantId\"   - \"ingredients\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findRecipe(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling RecipeApi->findRecipe: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10]
 **offset** | **num**|  | [optional] [default to 0]
 **sort** | **String**|  | [optional] 
 **direction** | **String**|  | [optional] 
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;itemId\&quot;   - \&quot;variantId\&quot;   - \&quot;ingredients\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] 

### Return type

[**List<Recipe>**](Recipe.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getRecipeByID**
> Recipe getRecipeByID(authorization, xAPIKey, itemId)

Get Recipe By ID

Get Recipe By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RecipeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var itemId = itemId_example; // String | 

try { 
    var result = api_instance.getRecipeByID(authorization, xAPIKey, itemId);
    print(result);
} catch (e) {
    print("Exception when calling RecipeApi->getRecipeByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **itemId** | **String**|  | 

### Return type

[**Recipe**](Recipe.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateRecipeByID**
> Recipe updateRecipeByID(authorization, xAPIKey, itemId, body)

Update Recipe By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RecipeApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var itemId = itemId_example; // String | 
var body = new Recipe(); // Recipe | 

try { 
    var result = api_instance.updateRecipeByID(authorization, xAPIKey, itemId, body);
    print(result);
} catch (e) {
    print("Exception when calling RecipeApi->updateRecipeByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **itemId** | **String**|  | 
 **body** | [**Recipe**](Recipe.md)|  | 

### Return type

[**Recipe**](Recipe.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
